@@ -8,7 +8,6 @@
 
 //! Data messages and their possible responses.
 
-mod chunk;
 mod cmd;
 mod data_exchange;
 mod errors;
@@ -16,7 +15,6 @@ mod query;
 mod register;
 
 pub use self::{
-    chunk::{ChunkRead, ChunkWrite},
     cmd::DataCmd,
     data_exchange::{
         ChunkDataExchange, ChunkMetadata, DataExchange, HolderMetadata, RegisterDataExchange,
@@ -30,7 +28,7 @@ pub use self::{
 use crate::messaging::{data::Error as ErrorMessage, MessageId};
 use crate::types::{
     register::{Entry, EntryHash, Permissions, Policy, Register},
-    Chunk, DataAddress, PublicKey,
+    Chunk, ChunkAddress, DataAddress, PublicKey,
 };
 use bytes::Bytes;
 use serde::{Deserialize, Serialize};
@@ -41,6 +39,13 @@ use xor_name::XorName;
 /// TODO: make uniquer per requester for some operations
 pub type OperationId = String;
 
+/// Return operation Id of a chunk
+pub fn operation_id(address: &ChunkAddress) -> Result<OperationId> {
+    address
+        .encode_to_zbase32()
+        .map_err(|_| Error::NoOperationId)
+}
+
 /// A message indicating that an error occurred as a node was handling a client's message.
 #[allow(clippy::large_enum_variant)]
 #[derive(Debug, Eq, PartialEq, Clone, Serialize, Deserialize)]
@@ -269,7 +274,8 @@ try_from!(Permissions, GetRegisterUserPermissions);
 #[cfg(test)]
 mod tests {
     use super::*;
-    use crate::types::{Keypair, PrivateChunk};
+    use crate::types::{utils::random_bytes, Chunk, Keypair};
+    use bytes::Bytes;
     use eyre::{eyre, Result};
     use std::convert::{TryFrom, TryInto};
 
@@ -312,9 +318,7 @@ mod tests {
             None => return Err(eyre!("Could not generate public key")),
         };
 
-        let owner = PublicKey::Bls(bls::SecretKey::random().public_key());
-
-        let i_data = Chunk::Private(PrivateChunk::new(vec![1, 3, 1, 4], owner));
+        let i_data = Chunk::new(Bytes::from(vec![1, 3, 1, 4]));
         let e = Error::AccessDenied(key);
         assert_eq!(
             i_data,
@@ -329,4 +333,31 @@ mod tests {
 
         Ok(())
     }
+
+    #[test]
+    fn wire_msg_payload() -> Result<()> {
+        use crate::messaging::data::DataCmd;
+        use crate::messaging::data::ServiceMsg;
+        use crate::messaging::WireMsg;
+
+        let chunks = (0..10).map(|_| Chunk::new(random_bytes(3072)));
+
+        for chunk in chunks {
+            let (original_msg, serialised_cmd) = {
+                let msg = ServiceMsg::Cmd(DataCmd::StoreChunk(chunk));
+                let bytes = WireMsg::serialize_msg_payload(&msg)?;
+                (msg, bytes)
+            };
+            let deserialized_msg: ServiceMsg =
+                rmp_serde::from_slice(&serialised_cmd).map_err(|err| {
+                    crate::messaging::Error::FailedToParse(format!(
+                        "Data message payload as Msgpack: {}",
+                        err
+                    ))
+                })?;
+            assert_eq!(original_msg, deserialized_msg);
+        }
+
+        Ok(())
+    }
 }
